@@ -3,6 +3,7 @@
 
 from typing import Any, Dict, NamedTuple, Optional, Union
 
+from .odxlink import OdxLinkId
 
 class EncodeState(NamedTuple):
     """Utility class to be used while encoding a message.
@@ -23,7 +24,7 @@ class EncodeState(NamedTuple):
     """a mapping from short name to value for each parameter"""
     triggering_request: Optional[Union[bytes, bytearray]] = None
     """If encoding a response: request that triggered the response"""
-    length_keys: Dict[str, int] = {}
+    length_keys: Dict[OdxLinkId, int] = {}
     """Mapping from IDs to bit lengths (specified by LengthKeyParameters)"""
     is_end_of_pdu: bool = False
     """Flag whether the parameter is the last on the PDU (needed for MinMaxLengthType)"""
