@@ -8,7 +8,7 @@ from .odxlink import OdxLinkRef, OdxLinkId, OdxDocFragment
 from .globals import logger
 from .dataobjectproperty import DopBase
 
-from .envdata import EnvironmentData, read_env_data_from_odx
+from .envdata import EnvironmentData
 from .decodestate import DecodeState
 from .encodestate import EncodeState
 from .exceptions import DecodeError, EncodeError
@@ -31,7 +31,43 @@ class EnvironmentDataDescription(DopBase):
         self.param_snref = param_snref
         self.param_snpathref = param_snpathref
 
-        # TODO: resolve the references!
+    @staticmethod
+    def from_et(et_element, doc_frags: List[OdxDocFragment]) \
+            -> "EnvironmentDataDescription":
+        """Reads Environment Data Description from Diag Layer."""
+        odx_id = OdxLinkId.from_et(et_element, doc_frags)
+        assert odx_id is not None
+        short_name = et_element.findtext("SHORT-NAME")
+        long_name = et_element.findtext("LONG-NAME")
+        param_snref = None
+        if et_element.find("PARAM-SNREF") is not None:
+            param_snref = et_element.find("PARAM-SNREF").get("SHORT-NAME")
+        param_snpathref = None
+        if et_element.find("PARAM-SNPATHREF") is not None:
+            param_snpathref = et_element.find("PARAM-SNPATHREF").get("SHORT-NAME-PATH")
+        env_data_refs = []
+        for env_data_ref in et_element.iterfind("ENV-DATA-REFS/ENV-DATA-REF"):
+            ref = OdxLinkRef.from_et(env_data_ref, doc_frags)
+            assert ref is not None
+            env_data_refs.append(ref)
+
+        # ODX 2.0.0 says ENV-DATA-DESC could contain a list of ENV-DATAS
+        env_datas = []
+        for env_data_elem in et_element.iterfind("ENV-DATAS/ENV-DATA"):
+            env_data = EnvironmentData.from_et(env_data_elem, doc_frags)
+            env_datas.append(env_data)
+
+        logger.debug("Parsing ENV-DATA-DESC " + short_name)
+
+        return EnvironmentDataDescription(
+            odx_id=odx_id,
+            short_name=short_name,
+            long_name=long_name,
+            param_snref=param_snref,
+            param_snpathref=param_snpathref,
+            env_datas=env_datas,
+            env_data_refs=env_data_refs,
+        )
 
     def _build_odxlinks(self) -> Dict[OdxLinkId, Any]:
         odxlinks = {}
@@ -71,41 +107,3 @@ class EnvironmentDataDescription(DopBase):
         wire, this method just raises an DecodeError exception.
         """
         raise DecodeError("EnvironmentDataDescription DOPs cannot be encoded or decoded")
-
-
-def read_env_data_desc_from_odx(et_element, doc_frags: List[OdxDocFragment]) \
-    -> EnvironmentDataDescription:
-    """Reads Environment Data Description from Diag Layer."""
-    odx_id = OdxLinkId.from_et(et_element, doc_frags)
-    assert odx_id is not None
-    short_name = et_element.findtext("SHORT-NAME")
-    long_name = et_element.findtext("LONG-NAME")
-    param_snref = None
-    if et_element.find("PARAM-SNREF") is not None:
-        param_snref = et_element.find("PARAM-SNREF").get("SHORT-NAME")
-    param_snpathref = None
-    if et_element.find("PARAM-SNPATHREF") is not None:
-        param_snpathref = et_element.find("PARAM-SNPATHREF").get("SHORT-NAME-PATH")
-    env_data_refs = []
-    for env_data_ref in et_element.iterfind("ENV-DATA-REFS/ENV-DATA-REF"):
-        ref = OdxLinkRef.from_et(env_data_ref, doc_frags)
-        assert ref is not None
-        env_data_refs.append(ref)
-
-    # ODX 2.0.0 says ENV-DATA-DESC could contain a list of ENV-DATAS
-    env_datas = []
-    for env_data_elem in et_element.iterfind("ENV-DATAS/ENV-DATA"):
-        env_data = read_env_data_from_odx(env_data_elem, doc_frags)
-        env_datas.append(env_data)
-
-    logger.debug("Parsing ENV-DATA-DESC " + short_name)
-
-    return EnvironmentDataDescription(
-        odx_id=odx_id,
-        short_name=short_name,
-        long_name=long_name,
-        param_snref=param_snref,
-        param_snpathref=param_snpathref,
-        env_datas=env_datas,
-        env_data_refs=env_data_refs,
-    )
