@@ -13,7 +13,8 @@ class TableEntryParameter(Parameter):
                  byte_position=None,
                  bit_position=None,
                  semantic=None,
-                 description=None):
+                 description=None,
+                 **kwargs):
         super().__init__(
             short_name=short_name,
             long_name=long_name,
@@ -21,7 +22,8 @@ class TableEntryParameter(Parameter):
             bit_position=bit_position,
             parameter_type="TABLE-ENTRY",
             semantic=semantic,
-            description=description
+            description=description,
+            **kwargs
         )
         assert target in ["KEY", "STRUCT"]
         self.target = target
