@@ -6,13 +6,12 @@ from typing import Dict, List, Any, Literal, Optional, Union
 
 from .utils import short_name_as_id
 from .nameditemlist import NamedItemList
-from .utils import read_description_from_odx
+from .utils import create_description_from_et
 from .odxlink import OdxLinkRef, OdxLinkId, OdxLinkDatabase, OdxDocFragment
-from .specialdata import SpecialDataGroup, read_sdgs_from_odx
+from .specialdata import SpecialDataGroup, create_sdgs_from_et
 
 UnitGroupCategory = Literal["COUNTRY", "EQUIV-UNITS"]
 
-
 @dataclass
 class PhysicalDimension:
     """A physical dimension is a formal definition of a unit.
@@ -58,6 +57,45 @@ class PhysicalDimension:
     molar_amount_exp: int = 0
     luminous_intensity_exp: int = 0
 
+    @staticmethod
+    def from_et(et_element, doc_frags: List[OdxDocFragment]) \
+            -> "PhysicalDimension":
+        odx_id = OdxLinkId.from_et(et_element, doc_frags)
+        assert odx_id is not None
+        oid = et_element.get("OID")
+        short_name = et_element.findtext("SHORT-NAME")
+        long_name = et_element.findtext("LONG-NAME")
+        description = create_description_from_et(et_element.find("DESC"))
+
+        def read_optional_int(element, name):
+            if element.findtext(name):
+                return int(element.findtext(name))
+            else:
+                return 0
+
+        length_exp = read_optional_int(et_element, "LENGTH-EXP")
+        mass_exp = read_optional_int(et_element, "MASS-EXP")
+        time_exp = read_optional_int(et_element, "TIME-EXP")
+        current_exp = read_optional_int(et_element, "CURRENT-EXP")
+        temperature_exp = read_optional_int(et_element, "TEMPERATURE-EXP")
+        molar_amount_exp = read_optional_int(et_element, "MOLAR-AMOUNT-EXP")
+        luminous_intensity_exp = read_optional_int(et_element,
+                                                   "LUMINOUS-INTENSITY-EXP")
+
+        return PhysicalDimension(
+            odx_id=odx_id,
+            short_name=short_name,
+            oid=oid,
+            long_name=long_name,
+            description=description,
+            length_exp=length_exp,
+            mass_exp=mass_exp,
+            time_exp=time_exp,
+            current_exp=current_exp,
+            temperature_exp=temperature_exp,
+            molar_amount_exp=molar_amount_exp,
+            luminous_intensity_exp=luminous_intensity_exp
+        )
 
 @dataclass
 class Unit:
@@ -113,6 +151,38 @@ class Unit:
     def __post_init__(self):
         self._physical_dimension = None
 
+    @staticmethod
+    def from_et(et_element, doc_frags: List[OdxDocFragment]) \
+            -> "Unit":
+        odx_id = OdxLinkId.from_et(et_element, doc_frags)
+        assert odx_id is not None
+        oid = et_element.get("OID")
+        short_name = et_element.findtext("SHORT-NAME")
+        long_name = et_element.findtext("LONG-NAME")
+        description = create_description_from_et(et_element.find("DESC"))
+        display_name = et_element.findtext("DISPLAY-NAME")
+
+        def read_optional_float(element, name):
+            if element.findtext(name):
+                return float(element.findtext(name))
+            else:
+                return None
+        factor_si_to_unit = read_optional_float(et_element, "FACTOR-SI-TO-UNIT")
+        offset_si_to_unit = read_optional_float(et_element, "OFFSET-SI-TO-UNIT")
+        physical_dimension_ref = OdxLinkRef.from_et(et_element.find("PHYSICAL-DIMENSION-REF"), doc_frags)
+
+        return Unit(
+            odx_id=odx_id,
+            short_name=short_name,
+            display_name=display_name,
+            oid=oid,
+            long_name=long_name,
+            description=description,
+            factor_si_to_unit=factor_si_to_unit,
+            offset_si_to_unit=offset_si_to_unit,
+            physical_dimension_ref=physical_dimension_ref,
+        )
+
     @property
     def physical_dimension(self) -> PhysicalDimension:
         return self._physical_dimension
@@ -143,6 +213,32 @@ class UnitGroup:
     def __post_init__(self):
         self._units = NamedItemList[Unit](short_name_as_id)
 
+    @staticmethod
+    def from_et(et_element, doc_frags: List[OdxDocFragment]) \
+            -> "UnitGroup":
+        oid = et_element.get("OID")
+        short_name = et_element.findtext("SHORT-NAME")
+        long_name = et_element.findtext("LONG-NAME")
+        description = create_description_from_et(et_element.find("DESC"))
+        category = et_element.findtext("CATEGORY")
+        assert category in [
+            "COUNTRY", "EQUIV-UNITS"], f'A UNIT-GROUP-CATEGORY must be "COUNTRY" or "EQUIV-UNITS". It was {category}.'
+        unit_refs = []
+
+        for el in et_element.iterfind("UNIT-REFS/UNIT-REF"):
+            ref = OdxLinkRef.from_et(el, doc_frags)
+            assert isinstance(ref, OdxLinkRef)
+            unit_refs.append(ref)
+
+        return UnitGroup(
+            short_name=short_name,
+            category=category,
+            unit_refs=unit_refs,
+            oid=oid,
+            long_name=long_name,
+            description=description
+        )
+
     def _resolve_references(self, odxlinks: OdxLinkDatabase):
         self._units = NamedItemList[Unit](
             short_name_as_id,
@@ -179,6 +275,24 @@ class UnitSpec:
         self.units = NamedItemList(short_name_as_id, self.units)
         self.physical_dimensions = NamedItemList(short_name_as_id, self.physical_dimensions)
 
+    @staticmethod
+    def from_et(et_element, doc_frags: List[OdxDocFragment]):
+
+        unit_groups = [UnitGroup.from_et(el, doc_frags)
+                       for el in et_element.iterfind("UNIT-GROUPS/UNIT-GROUP")]
+        units = [Unit.from_et(el, doc_frags)
+                 for el in et_element.iterfind("UNITS/UNIT")]
+        physical_dimensions = [PhysicalDimension.from_et(el, doc_frags)
+                               for el in et_element.iterfind("PHYSICAL-DIMENSIONS/PHYSICAL-DIMENSION")]
+        sdgs = create_sdgs_from_et(et_element.find("SDGS"), doc_frags)
+
+        return UnitSpec(
+            unit_groups=unit_groups,
+            units=units,
+            physical_dimensions=physical_dimensions,
+            sdgs=sdgs,
+        )
+
     def _build_odxlinks(self) -> Dict[OdxLinkId, Any]:
         odxlinks = {}
         odxlinks.update({
@@ -200,115 +314,3 @@ class UnitSpec:
             group._resolve_references(odxlinks)
         for sdg in self.sdgs:
             sdg._resolve_references(odxlinks)
-
-def read_unit_from_odx(et_element, doc_frags: List[OdxDocFragment]):
-    odx_id = OdxLinkId.from_et(et_element, doc_frags)
-    assert odx_id is not None
-    oid = et_element.get("OID")
-    short_name = et_element.findtext("SHORT-NAME")
-    long_name = et_element.findtext("LONG-NAME")
-    description = read_description_from_odx(et_element.find("DESC"))
-    display_name = et_element.findtext("DISPLAY-NAME")
-
-    def read_optional_float(element, name):
-        if element.findtext(name):
-            return float(element.findtext(name))
-        else:
-            return None
-    factor_si_to_unit = read_optional_float(et_element, "FACTOR-SI-TO-UNIT")
-    offset_si_to_unit = read_optional_float(et_element, "OFFSET-SI-TO-UNIT")
-    physical_dimension_ref = OdxLinkRef.from_et(et_element.find("PHYSICAL-DIMENSION-REF"), doc_frags)
-
-    return Unit(
-        odx_id=odx_id,
-        short_name=short_name,
-        display_name=display_name,
-        oid=oid,
-        long_name=long_name,
-        description=description,
-        factor_si_to_unit=factor_si_to_unit,
-        offset_si_to_unit=offset_si_to_unit,
-        physical_dimension_ref=physical_dimension_ref,
-    )
-
-
-def read_physical_dimension_from_odx(et_element, doc_frags: List[OdxDocFragment]):
-    odx_id = OdxLinkId.from_et(et_element, doc_frags)
-    assert odx_id is not None
-    oid = et_element.get("OID")
-    short_name = et_element.findtext("SHORT-NAME")
-    long_name = et_element.findtext("LONG-NAME")
-    description = read_description_from_odx(et_element.find("DESC"))
-
-    def read_optional_int(element, name):
-        if element.findtext(name):
-            return int(element.findtext(name))
-        else:
-            return 0
-
-    length_exp = read_optional_int(et_element, "LENGTH-EXP")
-    mass_exp = read_optional_int(et_element, "MASS-EXP")
-    time_exp = read_optional_int(et_element, "TIME-EXP")
-    current_exp = read_optional_int(et_element, "CURRENT-EXP")
-    temperature_exp = read_optional_int(et_element, "TEMPERATURE-EXP")
-    molar_amount_exp = read_optional_int(et_element, "MOLAR-AMOUNT-EXP")
-    luminous_intensity_exp = read_optional_int(et_element,
-                                               "LUMINOUS-INTENSITY-EXP")
-
-    return PhysicalDimension(
-        odx_id=odx_id,
-        short_name=short_name,
-        oid=oid,
-        long_name=long_name,
-        description=description,
-        length_exp=length_exp,
-        mass_exp=mass_exp,
-        time_exp=time_exp,
-        current_exp=current_exp,
-        temperature_exp=temperature_exp,
-        molar_amount_exp=molar_amount_exp,
-        luminous_intensity_exp=luminous_intensity_exp
-    )
-
-
-def read_unit_group_from_odx(et_element, doc_frags: List[OdxDocFragment]):
-    oid = et_element.get("OID")
-    short_name = et_element.findtext("SHORT-NAME")
-    long_name = et_element.findtext("LONG-NAME")
-    description = read_description_from_odx(et_element.find("DESC"))
-    category = et_element.findtext("CATEGORY")
-    assert category in [
-        "COUNTRY", "EQUIV-UNITS"], f'A UNIT-GROUP-CATEGORY must be "COUNTRY" or "EQUIV-UNITS". It was {category}.'
-    unit_refs = []
-
-    for el in et_element.iterfind("UNIT-REFS/UNIT-REF"):
-        ref = OdxLinkRef.from_et(el, doc_frags)
-        assert isinstance(ref, OdxLinkRef)
-        unit_refs.append(ref)
-
-    return UnitGroup(
-        short_name=short_name,
-        category=category,
-        unit_refs=unit_refs,
-        oid=oid,
-        long_name=long_name,
-        description=description
-    )
-
-
-def read_unit_spec_from_odx(et_element, doc_frags: List[OdxDocFragment]):
-
-    unit_groups = [read_unit_group_from_odx(el, doc_frags)
-                   for el in et_element.iterfind("UNIT-GROUPS/UNIT-GROUP")]
-    units = [read_unit_from_odx(el, doc_frags)
-             for el in et_element.iterfind("UNITS/UNIT")]
-    physical_dimensions = [read_physical_dimension_from_odx(el, doc_frags)
-                           for el in et_element.iterfind("PHYSICAL-DIMENSIONS/PHYSICAL-DIMENSION")]
-    sdgs = read_sdgs_from_odx(et_element.find("SDGS"), doc_frags)
-
-    return UnitSpec(
-        unit_groups=unit_groups,
-        units=units,
-        physical_dimensions=physical_dimensions,
-        sdgs=sdgs,
-    )
